fast_cor: Fast computation of correlation

View source: R/utils.R

fast_corR Documentation

Fast computation of correlation

Description

This uses a more memory-intensive but much faster algorithm than the built-in cor function.

Usage

fast_cor(x, y)

Arguments

x

first input matrix

y

second input matrix

Details

Computes the correlation between the columns of x and y.

Value

Correlations matrix between the columns of x and y


scregclust documentation built on April 5, 2026, 5:06 p.m.