| fast_cor | R Documentation |
This uses a more memory-intensive but much faster algorithm than
the built-in cor function.
fast_cor(x, y)
x |
first input matrix |
y |
second input matrix |
Computes the correlation between the columns of x and y.
Correlations matrix between the columns of x and y
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.